export class Main extends Indicator {

    constructor() {
        super();

        this.setProperty(Property.SeparateWindow, true);

        this.addInput("AtrPeriod", InputType.int, 14);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            AtrBuffer : this.addBuffer()
        };

        this.arr = {
            TempBuffer : [],
        };
    }

    onInit() {
        let {AtrPeriod} = this.getInputs();

        this.buffers.AtrBuffer
            .setShape(Shape.Line)
            .setColor(Color.DodgerBlue)
            .setLabel("ATR(" + AtrPeriod + ")")
            .setDrawBegin(AtrPeriod)
            .setShortName("ATR(" + AtrPeriod + ")")
        ;
    }

    async onUpdate() {
        const  {AtrPeriod, PriceType} = this.getInputs(),
            {TempBuffer} = this.arr,
            {AtrBuffer} = this.buffers,
            {
                High,
                Low,
                Close,
            } = await Bar.load([
                Bar.Mode.High,
                Bar.Mode.Low,
                Bar.Mode.Close,
            ], PriceType),
            barSize = Close.length;
        ;

        let i, countedBars = Bar.counted(), high_, low_, limit;

        if (barSize <= AtrPeriod) return 0;

        if (countedBars < 1) {
            for (i = 1; i <= AtrPeriod; i++) {
                AtrBuffer.set((barSize - i), 0);
            }
        }
        i = barSize - countedBars - 1;

        while (i >= 0) {
            high_ = High[i];
            low_ = Low[i];
            if (i === barSize - 1) {
                TempBuffer[i] = high_ - low_;
            }
            else {
                TempBuffer[i] = Math.max(high_, Close[i + 1]) - Math.min(low_, Close[i + 1]);
            }
            i--;
        }
        if (countedBars > 0) countedBars--;
        limit = barSize - countedBars;

        AtrBuffer.fill(Indicators.MAOnArray(TempBuffer, barSize, AtrPeriod, 0, Averaging.Simple));
    }
}